[dhewm3] 06/13: Imported Upstream version 0+git20150226+dfsg

Tobias Frost tobi at moszumanska.debian.org
Thu Mar 12 10:25:02 UTC 2015


This is an automated email from the git hooks/post-receive script.

tobi pushed a commit to branch master
in repository dhewm3.

commit acfb03dbdc66f0e9c3cf7fdef1a1a56bf54cd6ac
Author: Tobias Frost <tobi at coldtobi.de>
Date:   Thu Mar 12 09:33:38 2015 +0100

    Imported Upstream version 0+git20150226+dfsg
---
 ChangeLog                        |  8 ++++
 neo/d3xp/gamesys/SysCvar.cpp     |  2 +-
 neo/d3xp/physics/Physics_AF.cpp  |  4 +-
 neo/framework/DeclAF.cpp         |  2 +-
 neo/game/gamesys/SysCvar.cpp     |  2 +-
 neo/game/physics/Physics_AF.cpp  |  4 +-
 neo/idlib/Lexer.cpp              |  2 +-
 neo/idlib/Parser.cpp             |  2 +-
 neo/renderer/jpeg_memory_src.cpp | 93 ----------------------------------------
 neo/renderer/jpeg_memory_src.h   | 24 -----------
 10 files changed, 17 insertions(+), 126 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 2b38632..2ba3504 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,11 @@
+2015-02-25  Daniel Gibson  <metalcaedes at gmail.com>
+
+	* Merge pull request #108 from coldtobi/master
+
+2015-02-25  Tobias Frost  <tobi at coldtobi.de>
+
+	* Fixing some spelling errors: s/unkown/unknown, s/seperate/separate. (#107)
+
 2013-09-17  Daniel Gibson  <metalcaedes at gmail.com>
 
 	* Merge pull request #88 from waldheinz/drop-minizip-of-usage
diff --git a/neo/d3xp/gamesys/SysCvar.cpp b/neo/d3xp/gamesys/SysCvar.cpp
index 5ed1b1a..e6e7069 100644
--- a/neo/d3xp/gamesys/SysCvar.cpp
+++ b/neo/d3xp/gamesys/SysCvar.cpp
@@ -416,4 +416,4 @@ idCVar g_xp_bind_run_once( "g_xp_bind_run_once", "0", CVAR_GAME | CVAR_BOOL | CV
 
 idCVar net_serverDownload(			"net_serverDownload",		"0",			CVAR_GAME | CVAR_INTEGER | CVAR_ARCHIVE, "enable server download redirects. 0: off 1: redirect to si_serverURL 2: use builtin download. see net_serverDl cvars for configuration" );
 idCVar net_serverDlBaseURL(			"net_serverDlBaseURL",		"",				CVAR_GAME | CVAR_ARCHIVE, "base URL for the download redirection" );
-idCVar net_serverDlTable(			"net_serverDlTable",		"",				CVAR_GAME | CVAR_ARCHIVE, "pak names for which download is provided, seperated by ;" );
+idCVar net_serverDlTable(			"net_serverDlTable",		"",				CVAR_GAME | CVAR_ARCHIVE, "pak names for which download is provided, separated by ;" );
diff --git a/neo/framework/DeclAF.cpp b/neo/framework/DeclAF.cpp
index 2809f29..32bcf98 100644
--- a/neo/framework/DeclAF.cpp
+++ b/neo/framework/DeclAF.cpp
@@ -893,7 +893,7 @@ bool idDeclAF::ParseBody( idLexer &src ) {
 				src.Error( "custom models not yet implemented" );
 				return false;
 			} else {
-				src.Error( "unkown model type %s", token.c_str() );
+				src.Error( "unknown model type %s", token.c_str() );
 				return false;
 			}
 		} else if ( !token.Icmp( "origin" ) ) {
diff --git a/neo/game/gamesys/SysCvar.cpp b/neo/game/gamesys/SysCvar.cpp
index 9751ca8..34fee96 100644
--- a/neo/game/gamesys/SysCvar.cpp
+++ b/neo/game/gamesys/SysCvar.cpp
@@ -334,4 +334,4 @@ idCVar mod_validSkins(				"mod_validSkins",			"skins/characters/player/marine_mp
 
 idCVar net_serverDownload(			"net_serverDownload",		"0",			CVAR_GAME | CVAR_INTEGER | CVAR_ARCHIVE, "enable server download redirects. 0: off 1: redirect to si_serverURL 2: use builtin download. see net_serverDl cvars for configuration" );
 idCVar net_serverDlBaseURL(			"net_serverDlBaseURL",		"",				CVAR_GAME | CVAR_ARCHIVE, "base URL for the download redirection" );
-idCVar net_serverDlTable(			"net_serverDlTable",		"",				CVAR_GAME | CVAR_ARCHIVE, "pak names for which download is provided, seperated by ;" );
+idCVar net_serverDlTable(			"net_serverDlTable",		"",				CVAR_GAME | CVAR_ARCHIVE, "pak names for which download is provided, separated by ;" );
diff --git a/neo/idlib/Lexer.cpp b/neo/idlib/Lexer.cpp
index 4629a58..f125aea 100644
--- a/neo/idlib/Lexer.cpp
+++ b/neo/idlib/Lexer.cpp
@@ -192,7 +192,7 @@ const char *idLexer::GetPunctuationFromId( int id ) {
 			return idLexer::punctuations[i].p;
 		}
 	}
-	return "unkown punctuation";
+	return "unknown punctuation";
 }
 
 /*
diff --git a/neo/idlib/Parser.cpp b/neo/idlib/Parser.cpp
index a461a0e..931fd52 100644
--- a/neo/idlib/Parser.cpp
+++ b/neo/idlib/Parser.cpp
@@ -3144,7 +3144,7 @@ const char *idParser::GetPunctuationFromId( int id ) {
 			return idParser::punctuations[i].p;
 		}
 	}
-	return "unkown punctuation";
+	return "unknown punctuation";
 }
 
 /*
diff --git a/neo/renderer/jpeg_memory_src.cpp b/neo/renderer/jpeg_memory_src.cpp
deleted file mode 100644
index 287badc..0000000
--- a/neo/renderer/jpeg_memory_src.cpp
+++ /dev/null
@@ -1,93 +0,0 @@
-/*
- * Copyright (C) 1994-1996, Thomas G. Lane.
- * Modified 2009-2010 by Guido Vollbeding.
- * This file is part of the Independent JPEG Group's software.
- * For conditions of distribution and use, see the accompanying README file.
- *
- * This file contains decompression data source routines for the case of
- * reading JPEG data from memory or from a file (or any stdio stream).
- * While these routines are sufficient for most applications,
- * some will want to use a different source manager.
- * IMPORTANT: we assume that fread() will correctly transcribe an array of
- * JOCTETs from 8-bit-wide elements on external storage.  If char is wider
- * than 8 bits on your machine, you may need to do some tweaking.
- */
-
-#include "sys/platform.h"
-
-#include "renderer/jpeg_memory_src.h"
-
-#ifdef HAVE_JPEG_MEM_SRC
-void jpeg_memory_src(j_decompress_ptr cinfo, unsigned char *inbuffer, unsigned long insize) {
-	jpeg_mem_src(cinfo, inbuffer, insize);
-}
-#else
-static void init_mem_source(j_decompress_ptr cinfo) {
-	/* no work necessary here */
-}
-
-static boolean fill_mem_input_buffer(j_decompress_ptr cinfo) {
-	static JOCTET mybuffer[4];
-
-	/* The whole JPEG data is expected to reside in the supplied memory
-	 * buffer, so any request for more data beyond the given buffer size
-	 * is treated as an error.
-	 */
-	WARNMS(cinfo, JWRN_JPEG_EOF);
-	/* Insert a fake EOI marker */
-	mybuffer[0] = (JOCTET) 0xFF;
-	mybuffer[1] = (JOCTET) JPEG_EOI;
-
-	cinfo->src->next_input_byte = mybuffer;
-	cinfo->src->bytes_in_buffer = 2;
-
-	return TRUE;
-}
-
-static void skip_input_data(j_decompress_ptr cinfo, long num_bytes) {
-	struct jpeg_source_mgr *src = cinfo->src;
-
-	if (num_bytes > 0) {
-		while (num_bytes > (long)src->bytes_in_buffer) {
-			num_bytes -= (long)src->bytes_in_buffer;
-			(void)(*src->fill_input_buffer) (cinfo);
-			/* note we assume that fill_input_buffer will never return FALSE,
-			 * so suspension need not be handled.
-			 */
-		}
-		src->next_input_byte += (size_t)num_bytes;
-		src->bytes_in_buffer -= (size_t)num_bytes;
-	}
-}
-
-static void term_source(j_decompress_ptr cinfo)
-{
-	/* no work necessary here */
-}
-
-void jpeg_memory_src(j_decompress_ptr cinfo, unsigned char *inbuffer, unsigned long insize) {
-	struct jpeg_source_mgr *src;
-
-	if (inbuffer == NULL || insize == 0)	/* Treat empty input as fatal error */
-		ERREXIT(cinfo, JERR_INPUT_EMPTY);
-
-	/* The source object is made permanent so that a series of JPEG images
-	 * can be read from the same buffer by calling jpeg_mem_src only before
-	 * the first one.
-	 */
-	if (cinfo->src == NULL) {	/* first time for this JPEG object? */
-		cinfo->src = (struct jpeg_source_mgr *)
-			(*cinfo->mem->alloc_small)((j_common_ptr)cinfo, JPOOL_PERMANENT,
-										sizeof(struct jpeg_source_mgr));
-	}
-
-	src = cinfo->src;
-	src->init_source = init_mem_source;
-	src->fill_input_buffer = fill_mem_input_buffer;
-	src->skip_input_data = skip_input_data;
-	src->resync_to_restart = jpeg_resync_to_restart; /* use default method */
-	src->term_source = term_source;
-	src->bytes_in_buffer = (size_t)insize;
-	src->next_input_byte = (JOCTET *)inbuffer;
-}
-#endif
diff --git a/neo/renderer/jpeg_memory_src.h b/neo/renderer/jpeg_memory_src.h
deleted file mode 100644
index 2e8a58a..0000000
--- a/neo/renderer/jpeg_memory_src.h
+++ /dev/null
@@ -1,24 +0,0 @@
-/*
- * Copyright (C) 1994-1996, Thomas G. Lane.
- * Modified 2009-2010 by Guido Vollbeding.
- * This file is part of the Independent JPEG Group's software.
- * For conditions of distribution and use, see the accompanying README file.
- *
- * This file contains decompression data source routines for the case of
- * reading JPEG data from memory or from a file (or any stdio stream).
- * While these routines are sufficient for most applications,
- * some will want to use a different source manager.
- * IMPORTANT: we assume that fread() will correctly transcribe an array of
- * JOCTETs from 8-bit-wide elements on external storage.  If char is wider
- * than 8 bits on your machine, you may need to do some tweaking.
- */
-
-#ifndef __JPEG_MEMORY_SRC_H__
-#define __JPEG_MEMORY_SRC_H__
-
-#include <jpeglib.h>
-#include <jerror.h>
-
-void jpeg_memory_src(j_decompress_ptr cinfo, unsigned char *inbuffer, unsigned long insize);
-
-#endif

diff --git a/neo/d3xp/physics/Physics_AF.cpp b/neo/d3xp/physics/Physics_AF.cpp
index b716b74..098a4bf 100644
--- a/neo/d3xp/physics/Physics_AF.cpp
+++ b/neo/d3xp/physics/Physics_AF.cpp
@@ -3075,7 +3075,7 @@ void idAFConstraint_Contact::ApplyFriction( float invTimeStep ) {
 		return;
 	}
 
 	// seperate friction per contact is silly but it's fast and often looks close enough
 	if ( af_useImpulseFriction.GetBool() ) {
 
 		impulse.SetData( 6, VECX_ALLOCA( 6 ) );
@@ -6963,7 +6963,7 @@ void idPhysics_AF::BuildTrees( void ) {
 		}
 
 		if ( trees.Num() > 1 ) {
-			gameLocal.Warning( "Articulated figure has multiple seperate tree structures for entity '%s' type '%s'.",
+			gameLocal.Warning( "Articulated figure has multiple separate tree structures for entity '%s' type '%s'.",
 								self->name.c_str(), self->GetType()->classname );
 		}
 
@@ -3075,7 +3075,7 @@ void idAFConstraint_Contact::ApplyFriction( float invTimeStep ) {
 	}
 
-	// seperate friction per contact is silly but it's fast and often looks close enough
+	// separate friction per contact is silly but it's fast and often looks close enough
 	if ( af_useImpulseFriction.GetBool() ) {
 
diff --git a/neo/game/physics/Physics_AF.cpp b/neo/game/physics/Physics_AF.cpp
index 69ea4a2..3730480 100644
--- a/neo/game/physics/Physics_AF.cpp
+++ b/neo/game/physics/Physics_AF.cpp
@@ -3074,7 +3074,7 @@ void idAFConstraint_Contact::ApplyFriction( float invTimeStep ) {
 		return;
 	}
 
 	// seperate friction per contact is silly but it's fast and often looks close enough
 	if ( af_useImpulseFriction.GetBool() ) {
 
 		impulse.SetData( 6, VECX_ALLOCA( 6 ) );
@@ -6962,7 +6962,7 @@ void idPhysics_AF::BuildTrees( void ) {
 		}
 
 		if ( trees.Num() > 1 ) {
-			gameLocal.Warning( "Articulated figure has multiple seperate tree structures for entity '%s' type '%s'.",
+			gameLocal.Warning( "Articulated figure has multiple separate tree structures for entity '%s' type '%s'.",
 								self->name.c_str(), self->GetType()->classname );
 		}
 
@@ -3074,7 +3074,7 @@ void idAFConstraint_Contact::ApplyFriction( float invTimeStep ) {
 	}
 
-	// seperate friction per contact is silly but it's fast and often looks close enough
+	// separate friction per contact is silly but it's fast and often looks close enough
 	if ( af_useImpulseFriction.GetBool() ) {
 
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-games/dhewm3.git



More information about the Pkg-games-commits mailing list